@echo off
REM ----------------------------------------------------------
REM -- DRC/PA Online Assessment/CDT for the 2014-15 school year

set PKGNM=PA Online Assessment - CDT
set PKGSNAME=drc_insight

REM ----------------------------------------------------------

set LOGFILE=c:\ocs\%date:~10,4%_%date:~4,2%_%date:~7,2%_ocs.log
set MSILOG=c:\ocs\%date:~10,4%_%date:~4,2%_%date:~7,2%_%PKGSNAME%.log
set MSILOG2=c:\ocs\%date:~10,4%_%date:~4,2%_%date:~7,2%_%PKGSNAME%_2.log
set PWDIR=%~dp0
set MSICMD=
set QUIET=NO

set FlagFile=C:\pavcs\drc\cdt_flag.txt

mkdir c:\ocs > nul 2>&1
mkdir c:\pavcs\drc > nul 2>&1

echo =========  Start install %PKGNM%  %date% - %time% ============= >> %LOGFILE%

REM ====================================================================
REM  check for any command line options
REM  use the -q option when run via OCS to put in quiet mode
REM ====================================================================
    set arg=%1
    if "%arg%" == "-q" (
       set QUIET=YES
    )
echo [[ %DATE% %TIME% ]] Quiet option defined >> %LOGFILE%
REM ====================================================================
REM Check if I am on a 64-bit machine or not.  On the 64-bit machines,
REM OCS runs in a 32-bit command prompt.  But I need the installer to 
REM via the 64-bit command prompt.
REM ====================================================================
if exist %WINDIR%\sysnative\cmd.exe (
	REM I am on a 64bit machine, running the 32bit command prompt
	set MSICMD=%WINDIR%\sysnative\msiexec.exe
) ELSE (
	REM I must be on a 32bit machine, or already running at the 64bit
	REM command prompt
	set MSICMD=msiexec.exe
)
echo [[ %DATE% %TIME% ]] 32bit/64bit option defined >> %LOGFILE%

REM ====================================================================
REM    Check for Flag File
REM      -- Those computers that have had the latest CDT software
REM         installed previously will have the FlagFile created
REM         No need to do anything if the FlagFile is present
REM ====================================================================

if exist "%FlagFile%" (
	goto :flagfound
	)

REM ====================================================================
REM    Uninstall Previous Version
REM ====================================================================
if not %QUIET% == YES (
	echo Uninstalling previous version ... 
) else (
	echo [[ %DATE% %TIME% ]] Running Uninstaller....... >> %LOGFILE%
)

if exist "%MSILOG%" (
	del "%MSILOG%" >> %LOGFILE% 2>&1
	)

REM Uninstall 2013-14 version.
cmd.exe /S /C "start /wait %MSICMD% /x {C3A1DD88-E975-43C2-9D06-0B44AC59882C} /qn /L*v "%MSILOG%" " >> %LOGFILE% 2>&1

REM Because of the cmd always completing, there is no valid exit codes.

REM Uninstall any that have the 2014-15 version installed because
REM they don't have the install with the correct configs completed.
cmd.exe /S /C "start /wait %MSICMD% /x {34113A6D-07AD-433C-9320-B5EE498FEA71} /qn /L*v "%MSILOG%" " >> %LOGFILE% 2>&1

if %ERRORLEVEL% GEQ 1 (goto :failpre)


REM ====================================================================
REM    Install Stuff
REM ====================================================================

if exist "%MSILOG%" (
	del "%MSILOG%" >> %LOGFILE% 2>&1
	)

cmd.exe /S /C "start /wait %MSICMD% /i %PWDIR%\DRC_INSIGHT_Setup.msi /qn /L*v "%MSILOG%" HTTPS_PROXY="" OU_IDS="7JFUzUlwe" " >> %LOGFILE% 2>&1

REM Because of the cmd always completing, there is no valid exit codes.
REM only way to see if successful is to check the %MSILOG% file, 
REM and search for string
find /C /I "Product: DRC INSIGHT Online Learning System -- Installation completed successfully." "%MSILOG%" >> %LOGFILE%

if %ERRORLEVEL% GEQ 1 (goto :failinstall)


REM ====================================================================
REM    Post-Install Stuff
REM ====================================================================

echo Install completed >> %FlagFile%

if %ERRORLEVEL% GEQ 1 (goto :failpost) 


REM ====================================================================

goto :endgood

REM Something went really wrong if I get to this point
goto :endbad

REM ==============================================================
:flagfound
	echo [[ %DATE% %TIME% ]] FlagFile was found, not installing >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  0
		echo DATE:  %DATE% %TIME%
		echo Please verify that the program is working correctly before
		echo escalating.  If not, please escalate issue and include 
		echo package name, and error level
		echo 
		echo Press any key to close window
		pause > nul
	)
	exit

REM ==============================================================
:failpre
	echo [[ %DATE% %TIME% ]] Error occurred before install >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  6
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 6

REM ==============================================================
:failinstall
	echo [[ %DATE% %TIME% ]] Error occurred during install >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  8
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 8

REM ==============================================================
:failpost
	echo [[ %DATE% %TIME% ]] Error occurred after install >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  10
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 10

REM ==============================================================
:endbad
	echo [[ %DATE% %TIME% ]] Something went horribly wrong >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE:  100
		echo DATE:  %DATE% %TIME%
		echo Escalate issue and include package name, and error level
		echo Press any key to close window
		pause > nul
	)
	exit 100

REM ==============================================================
:endgood
	echo [[ %DATE% %TIME% ]] %PKGNM% completed with no errors reported >> %LOGFILE%
	if not %QUIET% == YES (
		echo PACKAGE: %PKGNM%
		echo ERROR CODE: 0
		echo DATE:  %DATE% %TIME%
		echo Package has completed successfully.
		echo Press any key to close window
		pause > nul
	)
	exit
